Learn R Programming

ciuupi2 (version 1.0.1)

bsspline2: Evaluate the functions b and s at x

Description

Evaluate the functions b and s, as specified by the vector (b(d/6),b(2d/6),...,b(5d/6),s(0),s(d/6),...,s(5d/6)) computed using bsciuupi2, alpha, m and natural at x.

Usage

bsspline2(x, bsvec, alpha, m, natural = 1)

Arguments

x

A value or vector of values at which the functions b and s are to be evaluated

bsvec

The vector \((b(d/6), b(2d/6), \dots, b(5d/6), s(0), s(d/6), \dots, s(5d/6))\) computed using bsciuupi2

alpha

The minimum coverage probability is 1 - alpha

m

Degrees of freedom n - p

natural

Equal to 1 (default) if the b and s functions are evaluated by natural cubic spline interpolation or 0 if evaluated by clamped cubic spline interpolation. This parameter must take the same value as that used in bsciuupi2

Value

A data frame containing x and the corresponding values of the functions b and s.

Details

The function b is an odd continuous function and the function s is an even continuous function. In addition, b(x)=0 and s(x) is equal to the \(1 - \alpha/2\) quantile of the \(t\) distribution with m degrees of freedom for all |x| greater than or equal to d, where d is a sufficiently large positive number (chosen by the function bsciuupi2). The values of these functions in the interval \([-d,d]\) are specified by the vector \((b(d/6), b(2d/6), \dots, b(5d/6), s(0), s(d/6), \dots, s(5d/6))\) as follows. By assumption, \(b(0)=0\) and \(b(-i)=-b(i)\) and \(s(-i)=s(i)\) for \(i=d/6,...,d\). The values of \(b(x)\) and \(s(x)\) for any \(x\) in the interval \([-d,d]\) are found using cubic spline interpolation for the given values of \(b(i)\) and \(s(i)\) for \(i=-d,-5d/6,...,0,d/6,...,5d/6,d\). The choices of \(d\) for \(m = 1, 2\) and \(>2\) are \(d=20, 10\) and \(6\) respectively.

The vector \((b(d/6), b(2d/6), \dots, b(5d/6), s(0), s(d/6), \dots, s(5d/6))\) that specifies the Kabaila and Giri(2009) confidence interval that utilizes uncertain prior information (CIUUPI), with minimum coverage probability 1 - alpha, is obtained using bsciuupi2.

In the examples, we continue with the same 2 x 2 factorial example described in the documentation for find_rho.

References

Kabaila, P. and Giri, R. (2009). Confidence intervals in regression utilizing prior information. Journal of Statistical Planning and Inference, 139, 3419-3429.

See Also

find_rho, bsciuupi2

Examples

Run this code
# NOT RUN {
alpha <- 0.05
m <- 8

# Find the vector (b(d/6),...,b(5d/6),s(0),...,s(5d/6)) that specifies the
# Kabaila & Giri (2009) CIUUPI for the first definition of the
# scaled expected length (default) (takes about 30 mins to run):
# }
# NOT RUN {
bsvec <- bsciuupi2(alpha, m, rho = -0.7071068)
# }
# NOT RUN {
# The result bsvec is (to 7 decimal places) the following:
bsvec <- c(-0.0287487, -0.2151595, -0.3430403, -0.3125889, -0.0852146,
            1.9795390,  2.0665414,  2.3984471,  2.6460159,  2.6170066,  2.3925494)

# Graph the functions b and s
x <- seq(0, 8, by = 0.1)
splineval <- bsspline2(x, bsvec, alpha, m)

plot(x, splineval[, 2], type = "l", main = "b function",
ylab = " ", las = 1, lwd = 2, xaxs = "i", col = "blue")
plot(x, splineval[, 3], type = "l", main = "s function",
ylab = " ", las = 1, lwd = 2, xaxs = "i",  col = "blue")

# }

Run the code above in your browser using DataLab